@@ -1,5 +1,5 @@
 /* twoftpd-bind-port.c -- twoftpd port (20) binding hack
- * Copyright (C) 2002  Bruce Guenter <bruceg@em.ca>
+ * Copyright (C) 2008  Bruce Guenter <bruce@untroubled.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -95,7 +95,7 @@ int main(int argc, char* argv[])
   }
 
   if ((tmp = getenv("TCPLOCALIP")) == 0 ||
-      !ipv4_parse(tmp, &ip, &end) ||
+      (end = ipv4_scan(tmp, &ip)) == 0 ||
       *end != 0) {
     respond(421, 1, "Configuration error, $TCPLOCALIP is not set or is invalid.");
     return 0;
