@@ -1,5 +1,5 @@
 /* twoftpd-drop.c - Main dispatch table for twoftpd-drop
- * Copyright (C) 2005  Bruce Guenter <bruceg@em.ca>
+ * Copyright (C) 2008  Bruce Guenter <bruce@untroubled.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include <unistd.h>
 #include "twoftpd.h"
 #include "backend.h"
 
@@ -27,11 +28,9 @@ int store_exclusive = 1;
  * their sake. */
 static int fake_list(void)
 {
-  obuf out;
-  if (!make_out_connection(&out)) return 1;
-  if (!close_out_connection(&out))
-    return respond(426, 1, "Listing aborted");
-  return respond(226, 1, "Listing complete");
+  int out;
+  if ((out = make_out_connection()) == -1) return 1;
+  return respond_xferresult(close(out), 0, 1);
 }
 
 const command verbs[] = {
